==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/migrate/kotlin/inputs/IISWorkloadInstanceModelCustomPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.migrate.kotlin.inputs

import com.pulumi.azurenative.migrate.inputs.IISWorkloadInstanceModelCustomPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * IIS workload instance model custom properties.
 * @property containerName Gets or sets the container Id.
 * @property fileshareName Gets or sets the fileshare name.
 * @property iisWebApplication IISWeb application.
 * @property instanceType Gets or sets the instance type.
 * Expected value is 'IISWorkloadInstanceModelCustomProperties'.
 * @property webAppArmId Gets or sets the Web application ARM id.
 * @property webAppSiteName Gets or sets the Web application site name.
 */
public data class IISWorkloadInstanceModelCustomPropertiesArgs(
    public val containerName: Output<String>? = null,
    public val fileshareName: Output<String>? = null,
    public val iisWebApplication: Output<IISWebApplicationArgs>? = null,
    public val instanceType: Output<String>,
    public val webAppArmId: Output<String>? = null,
    public val webAppSiteName: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.migrate.inputs.IISWorkloadInstanceModelCustomPropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.migrate.inputs.IISWorkloadInstanceModelCustomPropertiesArgs =
        com.pulumi.azurenative.migrate.inputs.IISWorkloadInstanceModelCustomPropertiesArgs.builder()
            .containerName(containerName?.applyValue({ args0 -> args0 }))
            .fileshareName(fileshareName?.applyValue({ args0 -> args0 }))
            .iisWebApplication(iisWebApplication?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .instanceType(instanceType.applyValue({ args0 -> args0 }))
            .webAppArmId(webAppArmId?.applyValue({ args0 -> args0 }))
            .webAppSiteName(webAppSiteName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [IISWorkloadInstanceModelCustomPropertiesArgs].
 */
@PulumiTagMarker
public class IISWorkloadInstanceModelCustomPropertiesArgsBuilder internal constructor() {
    private var containerName: Output<String>? = null

    private var fileshareName: Output<String>? = null

    private var iisWebApplication: Output<IISWebApplicationArgs>? = null

    private var instanceType: Output<String>? = null

    private var webAppArmId: Output<String>? = null

    private var webAppSiteName: Output<String>? = null

    /**
     * @param value Gets or sets the container Id.
     */
    @JvmName("itgoepchwecaguny")
    public suspend fun containerName(`value`: Output<String>) {
        this.containerName = value
    }

    /**
     * @param value Gets or sets the fileshare name.
     */
    @JvmName("jwdnqtcmdnwsdrlr")
    public suspend fun fileshareName(`value`: Output<String>) {
        this.fileshareName = value
    }

    /**
     * @param value IISWeb application.
     */
    @JvmName("lwflrhjmafnvbpdc")
    public suspend fun iisWebApplication(`value`: Output<IISWebApplicationArgs>) {
        this.iisWebApplication = value
    }

    /**
     * @param value Gets or sets the instance type.
     * Expected value is 'IISWorkloadInstanceModelCustomProperties'.
     */
    @JvmName("jrlgilurpanjfajn")
    public suspend fun instanceType(`value`: Output<String>) {
        this.instanceType = value
    }

    /**
     * @param value Gets or sets the Web application ARM id.
     */
    @JvmName("funutjlmhtwqoxon")
    public suspend fun webAppArmId(`value`: Output<String>) {
        this.webAppArmId = value
    }

    /**
     * @param value Gets or sets the Web application site name.
     */
    @JvmName("ahpnssixntwnoikj")
    public suspend fun webAppSiteName(`value`: Output<String>) {
        this.webAppSiteName = value
    }

    /**
     * @param value Gets or sets the container Id.
     */
    @JvmName("acmqlfilvrbgxhpy")
    public suspend fun containerName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.containerName = mapped
    }

    /**
     * @param value Gets or sets the fileshare name.
     */
    @JvmName("mvcdrwmyiluefldp")
    public suspend fun fileshareName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.fileshareName = mapped
    }

    /**
     * @param value IISWeb application.
     */
    @JvmName("rsuxowfbxxijaptr")
    public suspend fun iisWebApplication(`value`: IISWebApplicationArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.iisWebApplication = mapped
    }

    /**
     * @param argument IISWeb application.
     */
    @JvmName("roodaihattlejtbs")
    public suspend fun iisWebApplication(argument: suspend IISWebApplicationArgsBuilder.() -> Unit) {
        val toBeMapped = IISWebApplicationArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.iisWebApplication = mapped
    }

    /**
     * @param value Gets or sets the instance type.
     * Expected value is 'IISWorkloadInstanceModelCustomProperties'.
     */
    @JvmName("dbkshjtkeghkigpv")
    public suspend fun instanceType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.instanceType = mapped
    }

    /**
     * @param value Gets or sets the Web application ARM id.
     */
    @JvmName("yhjmwdxhpsficfuo")
    public suspend fun webAppArmId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.webAppArmId = mapped
    }

    /**
     * @param value Gets or sets the Web application site name.
     */
    @JvmName("nekdhwqknygawxod")
    public suspend fun webAppSiteName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.webAppSiteName = mapped
    }

    internal fun build(): IISWorkloadInstanceModelCustomPropertiesArgs =
        IISWorkloadInstanceModelCustomPropertiesArgs(
            containerName = containerName,
            fileshareName = fileshareName,
            iisWebApplication = iisWebApplication,
            instanceType = instanceType ?: throw PulumiNullFieldException("instanceType"),
            webAppArmId = webAppArmId,
            webAppSiteName = webAppSiteName,
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/migrate/kotlin/inputs/IISWorkloadInstanceModelCustomPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.migrate.kotlin.inputs

import com.pulumi.azurenative.migrate.inputs.IISWorkloadInstanceModelCustomPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * IIS workload instance model custom properties.
 * @property containerName Gets or sets the container Id.
 * @property fileshareName Gets or sets the fileshare name.
 * @property iisWebApplication IISWeb application.
 * @property instanceType Gets or sets the instance type.
 * Expected value is 'IISWorkloadInstanceModelCustomProperties'.
 * @property webAppArmId Gets or sets the Web application ARM id.
 * @property webAppSiteName Gets or sets the Web application site name.
 */
public data class IISWorkloadInstanceModelCustomPropertiesArgs(
    public val containerName: Output<String>? = null,
    public val fileshareName: Output<String>? = null,
    public val iisWebApplication: Output<IISWebApplicationArgs>? = null,
    public val instanceType: Output<String>,
    public val webAppArmId: Output<String>? = null,
    public val webAppSiteName: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.migrate.inputs.IISWorkloadInstanceModelCustomPropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.migrate.inputs.IISWorkloadInstanceModelCustomPropertiesArgs =
        com.pulumi.azurenative.migrate.inputs.IISWorkloadInstanceModelCustomPropertiesArgs.builder()
            .containerName(containerName?.applyValue({ args0 -> args0 }))
            .fileshareName(fileshareName?.applyValue({ args0 -> args0 }))
            .iisWebApplication(iisWebApplication?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .instanceType(instanceType.applyValue({ args0 -> args0 }))
            .webAppArmId(webAppArmId?.applyValue({ args0 -> args0 }))
            .webAppSiteName(webAppSiteName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [IISWorkloadInstanceModelCustomPropertiesArgs].
 */
@PulumiTagMarker
public class IISWorkloadInstanceModelCustomPropertiesArgsBuilder internal constructor() {
    private var containerName: Output<String>? = null

    private var fileshareName: Output<String>? = null

    private var iisWebApplication: Output<IISWebApplicationArgs>? = null

    private var instanceType: Output<String>? = null

    private var webAppArmId: Output<String>? = null

    private var webAppSiteName: Output<String>? = null

    /**
     * @param value Gets or sets the container Id.
     */
    @JvmName("vrmdpmqhjdqlomsl")
    public suspend fun containerName(`value`: Output<String>) {
        this.containerName = value
    }

    /**
     * @param value Gets or sets the fileshare name.
     */
    @JvmName("jkpmcxjuhkkkargw")
    public suspend fun fileshareName(`value`: Output<String>) {
        this.fileshareName = value
    }

    /**
     * @param value IISWeb application.
     */
    @JvmName("nxrqqlvtqblbcguy")
    public suspend fun iisWebApplication(`value`: Output<IISWebApplicationArgs>) {
        this.iisWebApplication = value
    }

    /**
     * @param value Gets or sets the instance type.
     * Expected value is 'IISWorkloadInstanceModelCustomProperties'.
     */
    @JvmName("btmvejysoybdtdau")
    public suspend fun instanceType(`value`: Output<String>) {
        this.instanceType = value
    }

    /**
     * @param value Gets or sets the Web application ARM id.
     */
    @JvmName("mrrumfdwtiydijva")
    public suspend fun webAppArmId(`value`: Output<String>) {
        this.webAppArmId = value
    }

    /**
     * @param value Gets or sets the Web application site name.
     */
    @JvmName("wydypwlybipwuoot")
    public suspend fun webAppSiteName(`value`: Output<String>) {
        this.webAppSiteName = value
    }

    /**
     * @param value Gets or sets the container Id.
     */
    @JvmName("osrukaaqhrwhddda")
    public suspend fun containerName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.containerName = mapped
    }

    /**
     * @param value Gets or sets the fileshare name.
     */
    @JvmName("xgbdkkutmpcersyq")
    public suspend fun fileshareName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.fileshareName = mapped
    }

    /**
     * @param value IISWeb application.
     */
    @JvmName("eiwjktodxowuxcdg")
    public suspend fun iisWebApplication(`value`: IISWebApplicationArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.iisWebApplication = mapped
    }

    /**
     * @param argument IISWeb application.
     */
    @JvmName("ivmtixvepsphsown")
    public suspend fun iisWebApplication(argument: suspend IISWebApplicationArgsBuilder.() -> Unit) {
        val toBeMapped = IISWebApplicationArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.iisWebApplication = mapped
    }

    /**
     * @param value Gets or sets the instance type.
     * Expected value is 'IISWorkloadInstanceModelCustomProperties'.
     */
    @JvmName("migicnnltvbonxyi")
    public suspend fun instanceType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.instanceType = mapped
    }

    /**
     * @param value Gets or sets the Web application ARM id.
     */
    @JvmName("ampwtlambikxuvpf")
    public suspend fun webAppArmId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.webAppArmId = mapped
    }

    /**
     * @param value Gets or sets the Web application site name.
     */
    @JvmName("jrmrcfudoakgdtng")
    public suspend fun webAppSiteName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.webAppSiteName = mapped
    }

    internal fun build(): IISWorkloadInstanceModelCustomPropertiesArgs =
        IISWorkloadInstanceModelCustomPropertiesArgs(
            containerName = containerName,
            fileshareName = fileshareName,
            iisWebApplication = iisWebApplication,
            instanceType = instanceType ?: throw PulumiNullFieldException("instanceType"),
            webAppArmId = webAppArmId,
            webAppSiteName = webAppSiteName,
        )
}
